@@ -34,8 +34,6 @@ def check_rank(score: int):
 
 
 class StaticPath:
-    # util
-    slst_json = root.assets / ("slst.json")
     # B30
     B30_bg = root.assets / ("B30.png")
     mask = root.assets / ("mask.png")
@@ -68,6 +66,9 @@ class StaticPath:
     geosans_light = root.assets.font / ("GeosansLight.ttf")
     notosanscjksc_regular = root.assets.font / ("NotoSansCJKsc-Regular.otf")
     exo_semibold = root.assets.font / ("Exo-SemiBold.ttf")
+    # andreal style
+    rawv3bg_0 = root.assets.recent("RawV3Bg_0.png")
+    rawv3bg_1 = root.assets.recent("RawV3Bg_1.png")
 
     # Function
     @staticmethod
