@@ -1,12 +1,5 @@
 from PIL import Image, ImageFont, ImageDraw
-from .assets import StaticPath
-from typing import Tuple, Dict
-from time import localtime, strftime
-
-try:
-    import ujson as json
-except ImportError:
-    import json
+from typing import Tuple
 
 try:
     from numpy import average
@@ -45,19 +38,6 @@ def is_dark(color: Tuple[int, int, int]):
     )
 
 
-def player_time_format(time_stamp: int) -> str:
-    struct_time = localtime(time_stamp / 1000)
-    return strftime("%Y-%m-%d %H:%M:%S", struct_time)
-
-
-def get_song_info(song_id: str) -> Dict:
-    with open(StaticPath.slst_json, "r", encoding="UTF-8") as f:
-        slst = json.loads(f.read())
-    for i in slst["songs"]:
-        if i["id"] == song_id:
-            return i
-
-
 def choice_ptt_background(ptt: int):
     if ptt == -1:
         return "rating_off.png"
